==> haskell-microlens-aeson-2.3.0-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.3.0
id: microlens-aeson-2.3.0-GEMeq6ruNIg7cdCgpJMKNE
key: microlens-aeson-2.3.0-GEMeq6ruNIg7cdCgpJMKNE
license: MIT
copyright: Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colingw@gmail.com>
author: Colin Woodbury
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
abi: 32005e65d1019f897990acee3ed10b26
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal Paths_microlens_aeson
import-dirs: /usr/lib/ghc-8.6.1/site-local/microlens-aeson-2.3.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/microlens-aeson-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/microlens-aeson-2.3.0
hs-libraries: HSmicrolens-aeson-2.3.0-GEMeq6ruNIg7cdCgpJMKNE
depends:
    aeson-1.4.1.0-GPncuQLCkBq39NZScMfTsF
    attoparsec-0.13.2.2-HPD0YgNwhBr5J2x8QxeYlI base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    scientific-0.3.6.2-2Qg8WlJf6PLET7HqXRUMwz text-1.2.3.1
    unordered-containers-0.2.9.0-LB7iMl6A8usDj0EAzhnafU
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-aeson-2.3.0-49-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.3.0
id: microlens-aeson-2.3.0-HVYIw0tp1NfFaxAkhZJ0Mb
key: microlens-aeson-2.3.0-HVYIw0tp1NfFaxAkhZJ0Mb
license: MIT
copyright: Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colingw@gmail.com>
author: Colin Woodbury
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
abi: b8ccf8eea6efaf411033f2e9af923ae1
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal Paths_microlens_aeson
import-dirs: /usr/lib/ghc-8.6.2/site-local/microlens-aeson-2.3.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/microlens-aeson-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/microlens-aeson-2.3.0
hs-libraries: HSmicrolens-aeson-2.3.0-HVYIw0tp1NfFaxAkhZJ0Mb
depends:
    aeson-1.4.2.0-GPa03mfYORkG452ywvZ9uU
    attoparsec-0.13.2.2-CmkmuzHxC7WKLrfPgrn9Wq base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi text-1.2.3.1
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
